function bez = computebez_mdds2d(deg,m1)
%computebez_mdds2d --> Evaluation of Bernstein-Bezier polynomials 
%                      on a regular triangular grid.
%
%<Synopsis>
%  bez = computebez_mdds2d(deg,m1)
%
%<Description>
%  Computes the values of bivariate Bernstein-Bezier polynomials of  
%  degree deg on a regular triangular grid.
%
%<Input Parameters>
%  deg  --> Box-spline degree
%   
%  m1   --> parameter identifing the number of evaluation points  
%           (m1+1) per triangle edge
%
% <Output Parameters>
%  bez  --> bi-dimensional array containing the evaluations 
%           of all bivariate Bernstein-Bezier polynomials in all  
%           the N, N=(m1+1)*(m1+2)/2, points in the triangular grid.

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Number of Bernstein-Bezier polynomials per triangle
G=(deg+1)*(deg+2)/2;

u3=[0.0 0.0 1.0];
v3=[0.0 1.0 0.0];
w3=[1.0 0.0 0.0];

np=0;
for k2=0:m1
    for k1=0:m1-k2
        r=((m1-k1-k2)*u3(1) + k1*v3(1) + k2*w3(1))/m1;
        s=((m1-k1-k2)*u3(2) + k1*v3(2) + k2*w3(2))/m1;
        t=((m1-k1-k2)*u3(3) + k1*v3(3) + k2*w3(3))/m1;
        np=np+1;
        for ii=1:G
            v=zeros(G,1);
            v(ii)=1.0;   
            for k=1:deg
                i1=1;
                for i=1:deg-k+1
                    ic=i1;
                    for j=1:i
                        ici=ic+i;
                        ici1=ici+1;
                        v(ic)=r*v(ic)+s*v(ici)+t*v(ici1);
                        ic=ic+1;
                    end
                    i1=i1+i;
                end
            end
            bez(np,ii)=v(1);
        end
    end
end